==> factorio-headless-2.0.32-1-x86_64.pkg.tar.zst: usr/share/factorio/space-age/prototypes/ambient-sounds.lua <==
data:extend(
{
--- weight 10 is normal. The higher the number, the higher the probabilities to sound.
-------------------------------------------------------------------------------------VULCANUS

  {
    type = "ambient-sound",
    name = "vulcanus-3-hero",
    track_type = "hero-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-3-hero.ogg",
  },
  {
    type = "ambient-sound",
    name = "vulcanus-1",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-1.ogg",
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-2",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-2.ogg",
    weight = 7
  },
  {
    type = "ambient-sound",
    name = "vulcanus-3",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-3.ogg",
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-4",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-4.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "vulcanus-5",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-5.ogg",
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-6",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-6.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "vulcanus-7",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-7.ogg",
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-8",
    track_type = "main-track",
    planet = "vulcanus",
    sound = "__space-age__/sound/ambient/vulcanus/vulcanus-8.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/vulcanus/vulcanus-9/vulcanus-9"),
  require("__space-age__/sound/ambient/vulcanus/vulcanus-10/vulcanus-10"),
  require("__space-age__/sound/ambient/vulcanus/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/vulcanus/interlude-2/interlude-2"),

-------------------------------------------------------------------------------------GLEBA

  {
    type = "ambient-sound",
    name = "gleba-1-hero",
    track_type = "hero-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-1-hero.ogg",
  },
  {
    type = "ambient-sound",
    name = "gleba-1",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-1.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-2",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-2.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-3",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-3.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-4",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-4.ogg",
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "gleba-5",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-5.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-6",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-6.ogg",
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "gleba-8",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-8.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-9",
    track_type = "main-track",
    planet = "gleba",
    sound = "__space-age__/sound/ambient/gleba/gleba-9.ogg",
    weight = 8
  },
   {
    type = "ambient-sound",
    name = "gleba-10",
    track_type = "main-track",
    planet = "gleba",
    sound =
    {
      variations =
      {
        "__space-age__/sound/ambient/gleba/gleba-10-a.ogg",
        "__space-age__/sound/ambient/gleba/gleba-10-b.ogg",
        "__space-age__/sound/ambient/gleba/gleba-10-c.ogg",
      },
    },
    weight = 12,
  },
  require("__space-age__/sound/ambient/gleba/gleba-11/gleba-11"),
  require("__space-age__/sound/ambient/gleba/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/gleba/interlude-4/interlude-4"),

-------------------------------------------------------------------------------------FULGORA

  {
    type = "ambient-sound",
    name = "fulgora-hero",
    track_type = "hero-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-hero.ogg",
  },
  {
    type = "ambient-sound",
    name = "fulgora-1",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-1.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-2",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-2.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-3",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-3.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-4",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-4.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/fulgora/fulgora-5/fulgora-5"),
  {
    type = "ambient-sound",
    name = "fulgora-6",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-6.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-7",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-7.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-8",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-8.ogg",
    weight = 10
  },
    {
    type = "ambient-sound",
    name = "fulgora-9",
    track_type = "main-track",
    planet = "fulgora",
    sound = "__space-age__/sound/ambient/fulgora/fulgora-9.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/fulgora/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/fulgora/interlude-2/interlude-2"),
  require("__space-age__/sound/ambient/fulgora/interlude-3/interlude-3"),
  require("__space-age__/sound/ambient/fulgora/interlude-4/interlude-4"),
  require("__space-age__/sound/ambient/fulgora/interlude-5/interlude-5"),
  require("__space-age__/sound/ambient/fulgora/interlude-6/interlude-6"),

-------------------------------------------------------------------------------------AQUILO

  {
    type = "ambient-sound",
    name = "aquilo-4-hero",
    track_type = "hero-track",
    planet = "aquilo",
    sound = "__space-age__/sound/ambient/aquilo/aquilo-4-hero.ogg",
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-1/aquilo-1"),
  {
    type = "ambient-sound",
    name = "aquilo-2",
    track_type = "main-track",
    planet = "aquilo",
    sound = "__space-age__/sound/ambient/aquilo/aquilo-2.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "aquilo-3",
    track_type = "main-track",
    planet = "aquilo",
    sound = "__space-age__/sound/ambient/aquilo/aquilo-3.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "aquilo-4",
    track_type = "main-track",
    planet = "aquilo",
    sound = "__space-age__/sound/ambient/aquilo/aquilo-4.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-5/aquilo-5"),
  {
    type = "ambient-sound",
    name = "aquilo-6",
    track_type = "main-track",
    planet = "aquilo",
    sound = "__space-age__/sound/ambient/aquilo/aquilo-6.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-7/aquilo-7"),
  {
    type = "ambient-sound",
    name = "aquilo-8",
    track_type = "main-track",
    planet = "aquilo",
    sound = "__space-age__/sound/ambient/aquilo/aquilo-8.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "aquilo-9",
    track_type = "main-track",
    planet = "aquilo",
    sound = "__space-age__/sound/ambient/aquilo/aquilo-9.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-10/aquilo-10"),
  require("__space-age__/sound/ambient/aquilo/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/aquilo/interlude-2/interlude-2"),
  require("__space-age__/sound/ambient/aquilo/interlude-3/interlude-3"),
  require("__space-age__/sound/ambient/aquilo/interlude-4/interlude-4"),

-------------------------------------------------------------------------------------SPACE

  {
    type = "ambient-sound",
    name = "space-2-hero",
    track_type = "hero-track",
    sound = "__space-age__/sound/ambient/space/space-2-hero.ogg",
  },
  {
    type = "ambient-sound",
    name = "space-1",
    track_type = "main-track",
    sound = "__space-age__/sound/ambient/space/space-1.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "space-2",
    track_type = "main-track",
    sound = "__space-age__/sound/ambient/space/space-2.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/space/space-3/space-3"),
  {
    type = "ambient-sound",
    name = "space-5",
    track_type = "main-track",
    sound = "__space-age__/sound/ambient/space/space-5.ogg",
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "space-6",
    track_type = "main-track",
    sound = "__space-age__/sound/ambient/space/space-6.ogg",
    weight = 10
  },
  require("__space-age__/sound/ambient/space/space-9/space-9"),
  require("__space-age__/sound/ambient/space/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/space/interlude-2/interlude-2"),
  require("__space-age__/sound/ambient/space/interlude-3/interlude-3"),
  require("__space-age__/sound/ambient/space/interlude-5/interlude-5"),
  require("__space-age__/sound/ambient/space/interlude-6/interlude-6"),
})

==> factorio-headless-2.0.66-1-x86_64.pkg.tar.zst: usr/share/factorio/space-age/prototypes/ambient-sounds.lua <==
data:extend(
{
--- weight 10 is normal. The higher the number, the higher the probabilities to sound.
-------------------------------------------------------------------------------------VULCANUS

  {
    type = "ambient-sound",
    name = "vulcanus-3-hero",
    track_type = "hero-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-3-hero.ogg", volume = 0.7,},
  },
  {
    type = "ambient-sound",
    name = "vulcanus-1",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-1.ogg", volume = 0.7,},
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-2",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-2.ogg", volume = 0.7,},
    weight = 7
  },
  {
    type = "ambient-sound",
    name = "vulcanus-3",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-3.ogg", volume = 0.7,},
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-4",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-4.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "vulcanus-5",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-5.ogg", volume = 0.7,},
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-6",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-6.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "vulcanus-7",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-7.ogg", volume = 0.7,},
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "vulcanus-8",
    track_type = "main-track",
    planet = "vulcanus",
    sound = {filename = "__space-age__/sound/ambient/vulcanus/vulcanus-8.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/vulcanus/vulcanus-9/vulcanus-9"),
  require("__space-age__/sound/ambient/vulcanus/vulcanus-10/vulcanus-10"),
  require("__space-age__/sound/ambient/vulcanus/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/vulcanus/interlude-2/interlude-2"),

-------------------------------------------------------------------------------------GLEBA

  {
    type = "ambient-sound",
    name = "gleba-1-hero",
    track_type = "hero-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-1-hero.ogg", volume = 0.7,},
  },
  {
    type = "ambient-sound",
    name = "gleba-1",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-1.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-2",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-2.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-3",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-3.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-4",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-4.ogg", volume = 0.7,},
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "gleba-5",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-5.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-6",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-6.ogg", volume = 0.7,},
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "gleba-8",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-8.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "gleba-9",
    track_type = "main-track",
    planet = "gleba",
    sound = {filename = "__space-age__/sound/ambient/gleba/gleba-9.ogg", volume = 0.7,},
    weight = 8
  },
  {
    type = "ambient-sound",
    name = "gleba-10",
    track_type = "main-track",
    planet = "gleba",
    sound =
    {
      variations =
      {
        {filename = "__space-age__/sound/ambient/gleba/gleba-10-a.ogg", volume = 0.9,},
        {filename = "__space-age__/sound/ambient/gleba/gleba-10-b.ogg", volume = 1.0,},
        {filename = "__space-age__/sound/ambient/gleba/gleba-10-c.ogg", volume = 0.7,},
      },
    },
    weight = 12,
  },
  require("__space-age__/sound/ambient/gleba/gleba-11/gleba-11"),
  require("__space-age__/sound/ambient/gleba/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/gleba/interlude-4/interlude-4"),

-------------------------------------------------------------------------------------FULGORA

  {
    type = "ambient-sound",
    name = "fulgora-hero",
    track_type = "hero-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-hero.ogg", volume = 0.7,},
  },
  {
    type = "ambient-sound",
    name = "fulgora-1",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-1.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-2",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-2.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-3",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-3.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-4",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-4.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/fulgora/fulgora-5/fulgora-5"),
  {
    type = "ambient-sound",
    name = "fulgora-6",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-6.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-7",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-7.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-8",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-8.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "fulgora-9",
    track_type = "main-track",
    planet = "fulgora",
    sound = {filename = "__space-age__/sound/ambient/fulgora/fulgora-9.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/fulgora/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/fulgora/interlude-2/interlude-2"),
  require("__space-age__/sound/ambient/fulgora/interlude-3/interlude-3"),
  require("__space-age__/sound/ambient/fulgora/interlude-4/interlude-4"),
  require("__space-age__/sound/ambient/fulgora/interlude-5/interlude-5"),
  require("__space-age__/sound/ambient/fulgora/interlude-6/interlude-6"),

-------------------------------------------------------------------------------------AQUILO

  {
    type = "ambient-sound",
    name = "aquilo-3-hero",
    track_type = "hero-track",
    planet = "aquilo",
    sound = {filename = "__space-age__/sound/ambient/aquilo/aquilo-3-hero.ogg", volume = 0.7,},
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-1/aquilo-1"),
  {
    type = "ambient-sound",
    name = "aquilo-2",
    track_type = "main-track",
    planet = "aquilo",
    sound = {filename = "__space-age__/sound/ambient/aquilo/aquilo-2.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "aquilo-3",
    track_type = "main-track",
    planet = "aquilo",
    sound = {filename = "__space-age__/sound/ambient/aquilo/aquilo-3.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "aquilo-4",
    track_type = "main-track",
    planet = "aquilo",
    sound = {filename = "__space-age__/sound/ambient/aquilo/aquilo-4.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-5/aquilo-5"),
  {
    type = "ambient-sound",
    name = "aquilo-6",
    track_type = "main-track",
    planet = "aquilo",
    sound = {filename = "__space-age__/sound/ambient/aquilo/aquilo-6.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-7/aquilo-7"),
  {
    type = "ambient-sound",
    name = "aquilo-8",
    track_type = "main-track",
    planet = "aquilo",
    sound = {filename = "__space-age__/sound/ambient/aquilo/aquilo-8.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "aquilo-9",
    track_type = "main-track",
    planet = "aquilo",
    sound = {filename = "__space-age__/sound/ambient/aquilo/aquilo-9.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/aquilo/aquilo-10/aquilo-10"),
  require("__space-age__/sound/ambient/aquilo/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/aquilo/interlude-2/interlude-2"),
  require("__space-age__/sound/ambient/aquilo/interlude-3/interlude-3"),
  require("__space-age__/sound/ambient/aquilo/interlude-4/interlude-4"),

-------------------------------------------------------------------------------------SPACE

  {
    type = "ambient-sound",
    name = "space-2-hero",
    track_type = "hero-track",
    sound = {filename = "__space-age__/sound/ambient/space/space-2-hero.ogg", volume = 0.7,},
  },
  {
    type = "ambient-sound",
    name = "space-1",
    track_type = "main-track",
    sound = {filename = "__space-age__/sound/ambient/space/space-1.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "space-2",
    track_type = "main-track",
    sound = {filename = "__space-age__/sound/ambient/space/space-2.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/space/space-3/space-3"),
  {
    type = "ambient-sound",
    name = "space-5",
    track_type = "main-track",
    sound = {filename = "__space-age__/sound/ambient/space/space-5.ogg", volume = 0.7,},
    weight = 10
  },
  {
    type = "ambient-sound",
    name = "space-6",
    track_type = "main-track",
    sound = {filename = "__space-age__/sound/ambient/space/space-6.ogg", volume = 0.7,},
    weight = 10
  },
  require("__space-age__/sound/ambient/space/space-9/space-9"),
  require("__space-age__/sound/ambient/space/interlude-1/interlude-1"),
  require("__space-age__/sound/ambient/space/interlude-2/interlude-2"),
  require("__space-age__/sound/ambient/space/interlude-3/interlude-3"),
  require("__space-age__/sound/ambient/space/interlude-5/interlude-5"),
  require("__space-age__/sound/ambient/space/interlude-6/interlude-6"),
})
